@@ -12,6 +12,14 @@ TRUE_STRINGS = ('yes', 'true', 'y')
 FALSE_STRINGS = ('no', 'false', 'n')
 
 
+def update_in(obj, keys, value):
+    """Given a list of keys and a value, return a new object with that value set"""
+    cur_node = obj
+    for key in keys[:-1]:
+        cur_node = cur_node.setdefault(key, {})
+    cur_node[keys[-1]] = value
+
+
 def deep_merge(a, b):
     """Merges a and b, letting b win if there is a conflict"""
     merged = a.copy()
@@ -125,3 +133,8 @@ def is_service_current(service, current_token_etag, token_name):
                      for sources in service['source-tokens']
                      for source in sources)
     return is_current
+
+
+def is_admin_enabled():
+    """Returns True if current user is an admin"""
+    return str2bool(os.getenv('WAITER_ADMIN', default=FALSE_STRINGS[0]))
